@@ -10,15 +10,44 @@ use parse_duration::parse;
 
 pub const HISTORY_PAGE_SIZE: i64 = 100;
 
+#[derive(Clone, Debug, Deserialize, Copy)]
+pub enum SearchMode {
+    #[serde(rename = "prefix")]
+    Prefix,
+
+    #[serde(rename = "fulltext")]
+    FullText,
+}
+
+// FIXME: Can use upstream Dialect enum if https://github.com/stevedonovan/chrono-english/pull/16 is merged
+#[derive(Clone, Debug, Deserialize, Copy)]
+pub enum Dialect {
+    #[serde(rename = "us")]
+    Us,
+
+    #[serde(rename = "uk")]
+    Uk,
+}
+
+impl From<Dialect> for chrono_english::Dialect {
+    fn from(d: Dialect) -> chrono_english::Dialect {
+        match d {
+            Dialect::Uk => chrono_english::Dialect::Uk,
+            Dialect::Us => chrono_english::Dialect::Us,
+        }
+    }
+}
+
 #[derive(Clone, Debug, Deserialize)]
 pub struct Settings {
-    pub dialect: String,
+    pub dialect: Dialect,
     pub auto_sync: bool,
     pub sync_address: String,
     pub sync_frequency: String,
     pub db_path: String,
     pub key_path: String,
     pub session_path: String,
+    pub search_mode: SearchMode,
 
     // This is automatically loaded when settings is created. Do not set in
     // config! Keep secrets and settings apart.
@@ -54,7 +83,9 @@ impl Settings {
     }
 
     pub fn should_sync(&self) -> Result<bool> {
-        if !self.auto_sync {
+        let session_path = atuin_common::utils::data_dir().join("session");
+
+        if !self.auto_sync || !session_path.exists() {
             return Ok(false);
         }
 
@@ -69,13 +100,11 @@ impl Settings {
 
     pub fn new() -> Result<Self> {
         let config_dir = atuin_common::utils::config_dir();
-        let config_dir = config_dir.as_path();
 
         let data_dir = atuin_common::utils::data_dir();
-        let data_dir = data_dir.as_path();
 
-        create_dir_all(config_dir)?;
-        create_dir_all(data_dir)?;
+        create_dir_all(&config_dir)?;
+        create_dir_all(&data_dir)?;
 
         let mut config_file = if let Ok(p) = std::env::var("ATUIN_CONFIG_DIR") {
             PathBuf::from(p)
@@ -100,6 +129,7 @@ impl Settings {
         s.set_default("auto_sync", true)?;
         s.set_default("sync_frequency", "1h")?;
         s.set_default("sync_address", "https://api.atuin.sh")?;
+        s.set_default("search_mode", "prefix")?;
 
         if config_file.exists() {
             s.merge(ConfigFile::with_name(config_file.to_str().unwrap()))?;
