@@ -1,4 +1,4 @@
-#! /usr/bin/env sh
+#! /usr/bin/env bash
 
 set -euo pipefail
 
@@ -50,7 +50,7 @@ __atuin_install_arch(){
 __atuin_install_ubuntu(){
 	echo "Ubuntu detected"
 	# TODO: select correct AARCH too
-	ARTIFACT_URL="https://github.com/account/project/releases/download/$LATEST_VERSION/atuin_$LATEST_VERSION_amd64.deb"
+	ARTIFACT_URL="https://github.com/ellie/atuin/releases/download/$LATEST_VERSION/atuin_${LATEST_VERSION//v/}_amd64.deb"
 
 	TEMP_DEB="$(mktemp)" &&
 	wget -O "$TEMP_DEB" $ARTIFACT_URL
@@ -115,8 +115,9 @@ __atuin_install_cargo(){
 
 		echo "rustup installed! Attempting cargo install"
 
-		cargo install atuin
 	fi
+
+	cargo install atuin
 }
 
 __atuin_install_unsupported(){
@@ -145,8 +146,8 @@ case "$OSTYPE" in
 esac
 
 # TODO: Check which is in use
-echo 'eval "$(atuin init zsh)"' >> ~/.zshrc
+printf '\neval "$(atuin init zsh)"' >> ~/.zshrc
 
 curl https://raw.githubusercontent.com/rcaloras/bash-preexec/master/bash-preexec.sh -o ~/.bash-preexec.sh
-echo '[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh' >> ~/.bashrc
+printf '\n[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh' >> ~/.bashrc
 echo 'eval "$(atuin init bash)"' >> ~/.bashrc
